@@ -3,7 +3,7 @@ BEGIN {
   $WWW::DuckDuckGo::AUTHORITY = 'cpan:GETTY';
 }
 BEGIN {
-  $WWW::DuckDuckGo::VERSION = '0.001';
+  $WWW::DuckDuckGo::VERSION = '0.002';
 }
 # ABSTRACT: Access to the DuckDuckGo APIs
 
@@ -56,7 +56,7 @@ sub zeroclickinfo {
 		my $result = decode_json($res->content);
 		return $self->_zeroclickinfo_class->by($result);
 	} else {
-		die __PACKAGE__.': '.$res->status_line, "\n";
+		die __PACKAGE__.' HTTP request failed: '.$res->status_line, "\n";
 	}
 }
 
@@ -72,7 +72,7 @@ WWW::DuckDuckGo - Access to the DuckDuckGo APIs
 
 =head1 VERSION
 
-version 0.001
+version 0.002
 
 =head1 SYNOPSIS
 
@@ -80,15 +80,30 @@ version 0.001
 
   my $duck = WWW::DuckDuckGo;
   
-  # request the Zero Click Info, you can also use ..->zci('getty')
-  my $zeroclickinfo = $duck->zeroclickinfo('getty');
+  # request the Zero Click Info, you can also use ..->zci('duck duck go')
+  my $zeroclickinfo = $duck->zeroclickinfo('duck duck go');
+
+  # request the Zero Click Info of "duck duck go more stuff"
+  my $other_zeroclickinfo = $duck->zeroclickinfo('duck duck go','more stuff');
 
 =head1 DESCRIPTION
 
-This distribution gives you an easy access to the DuckDuckGo Zero Click Info API. (Documentation on the TODO, or do you wanna help?)
+This distribution gives you an easy access to the DuckDuckGo Zero Click Info API.
+
+=head1 METHODS
+
+=head2 $obj->zeroclickinfo
+
+Arguments: @query_fields
+
+Return value: L<WWW::DuckDuckGo::ZeroClickInfo>
+
+Returns the L<WWW::DuckDuckGo::ZeroClickInfo> of the query specified by the parameters. If you give several parameters they will get joined with an empty space.
 
 =encoding utf8
 
+=head1 METHODS
+
 =head1 SUPPORT
 
 IRC
