@@ -3,7 +3,7 @@ BEGIN {
   $WWW::DuckDuckGo::Link::AUTHORITY = 'cpan:GETTY';
 }
 BEGIN {
-  $WWW::DuckDuckGo::Link::VERSION = '0.001';
+  $WWW::DuckDuckGo::Link::VERSION = '0.002';
 }
 # ABSTRACT: A DuckDuckGo Link definition
 
@@ -44,6 +44,8 @@ has text => (
 );
 
 1;
+
+
 __END__
 =pod
 
@@ -53,7 +55,62 @@ WWW::DuckDuckGo::Link - A DuckDuckGo Link definition
 
 =head1 VERSION
 
-version 0.001
+version 0.002
+
+=head1 SYNOPSIS
+
+  use WWW::DuckDuckGo;
+
+  my $zci = WWW::DuckDuckGo->new->zci('duck duck go');
+  
+  for (@{$zci->related_topics}) {
+    print "Related Topic URL: ".$_->first_url."\n" if $_->has_first_url;
+  }
+
+=head1 DESCRIPTION
+
+This package reflects the result of a zeroclickinfo API request.
+
+=head1 METHODS
+
+=head2 has_result
+
+=head2 result
+
+=head2 has_first_url
+
+=head2 first_url
+
+Gives back a URI::http
+
+=head2 has_icon
+
+=head2 icon
+
+Gives back an L<WWW::DuckDuckGo::Icon> object.
+
+=head2 has_text
+
+=head2 text
+
+=encoding utf8
+
+=head1 METHODS
+
+=head1 SUPPORT
+
+IRC
+
+  Join #duckduckgo on irc.freenode.net. Highlight Getty for fast reaction :).
+
+Repository
+
+  http://github.com/Getty/p5-www-duckduckgo
+  Pull request and additional contributors are welcome
+
+Issue Tracker
+
+  http://github.com/Getty/p5-www-duckduckgo/issues
 
 =head1 AUTHOR
 
